import React, { useEffect, useState } from 'react';
import JSZip from 'jszip';

const Animation = () => {
  const [images, setImages] = useState([]);
  const [currentFrame, setCurrentFrame] = useState(0);
  const [loading, setLoading] = useState(true);
  const frameRate = 100; // Frame rate in milliseconds

  useEffect(() => {
    const loadImages = async () => {
      const zip = new JSZip();
      try {
        const response = await fetch('src/assets/characters/sprite.zip'); // Adjust the path to your ZIP file
        if (!response.ok) {
          throw new Error('Network response was not ok');
        }
        const data = await response.arrayBuffer();
        const zipContent = await zip.loadAsync(data);

        const imgPromises = [];
        zipContent.forEach((relativePath, file) => {
          if (file.name.endsWith('.webp')) {
            imgPromises.push(file.async('blob')); // Convert file to Blob
          }
        });

        const imgBlobs = await Promise.all(imgPromises);
        const imgUrls = imgBlobs.map(blob => URL.createObjectURL(blob)); // Create object URLs

        console.log('Loaded images:', imgUrls); // Log the loaded image URLs

        setImages(imgUrls);
      } catch (error) {
        console.error('Error loading images:', error);
      } finally {
        setLoading(false); // Set loading to false after images are loaded
      }
    };

    loadImages();

  }, []);

  useEffect(() => {
    const interval = setInterval(() => {
      setCurrentFrame((prevFrame) => (prevFrame + 1) % images.length);
    }, frameRate);

    return () => clearInterval(interval);
  }, [images]);

  useEffect(() => {
    // Cleanup object URLs when the component unmounts
    return () => {
      images.forEach(url => URL.revokeObjectURL(url)); // Clean up object URLs
    };
  }, [images]);

  if (loading) {
    return <div>Loading...</div>; // Show loading indicator
  } else {
    return (
      <div style={{ display: 'flex', justifyContent: 'center', alignItems: 'center' }}>
        {images.length > 0 && (
          <img
            src={images[currentFrame]}
            alt="Animation frame"
            style={{ maxWidth: '100%', height: 'auto' }} // Responsive image
          />
        )}
      </div>
    );
  }
};

export default Animation;
